@@ -62,6 +62,7 @@ public class NanoOKOptions implements Serializable {
     private int coverageBinSize = 100;
     private boolean processPassReads = true;
     private boolean processFailReads = true;
+    private boolean processSkipReads = true;
     private boolean parseAlignments = true;
     private boolean plotGraphs = true;
     private boolean makeReport = true;
@@ -153,7 +154,7 @@ public class NanoOKOptions implements Serializable {
         
         if (args.length <= 1) {
             System.out.println("");
-            System.out.println("Syntax nanook <extract|align|analyse|compare|process> [options]");
+            System.out.println("Syntax nanook <extract|align|analyse|compare|rt> [options]");
             System.out.println("");
             System.out.println("extract options:");
             System.out.println("    -s|-sample <dir> specifies sample directory");
@@ -173,6 +174,8 @@ public class NanoOKOptions implements Serializable {
             System.out.println("    -aligner <name> specifies the aligner (default last)"); 
             System.out.println("    -alignerparams <params> specifies paramters to the aligner");
             System.out.println("    -showaligns echoes aligner commands to screen");
+            System.out.println("    -a|-fasta specifies FASTA file input (default)");
+            System.out.println("    -q|-fastq specifies FASTQ file input");
             System.out.println("");
             System.out.println("analyse options:");
             System.out.println("    -s|-sample <dir> specifies sample directory");
@@ -186,7 +189,7 @@ public class NanoOKOptions implements Serializable {
             System.out.println("    -o|-outputdir <directory> specifies an output directory");
             System.out.println("    -type <2d|template|complement> specifies an output directory");
             System.out.println("");
-            System.out.println("process options:");
+            System.out.println("rt options:");
             System.out.println("    -process <file> specifies a process file");
             System.out.println("");
             //System.out.println("Sample type options:");
@@ -206,7 +209,7 @@ public class NanoOKOptions implements Serializable {
             System.out.println("    -force to force NanoOK to ignore warnings");
             System.out.println("    -timeout to set the number of seconds before giving up waiting for new reads (default 2)");
             System.out.println("");
-            System.out.println("Valid aligners: last, bwa, blasr, marginalign, graphmap");
+            System.out.println("Valid aligners: last, bwa, blasr, marginalign, graphmap, minimap2, ngmlr");
             System.out.println("");
             System.exit(0);
         }
@@ -243,7 +246,7 @@ public class NanoOKOptions implements Serializable {
             runMode = MODE_COMPARE;
         } else if (args[i].equals("watch")) {
             runMode = MODE_WATCH;
-        } else if ((args[i].equals("process")) || (args[i].equals("scan"))) {
+        } else if ((args[i].equals("process")) || (args[i].equals("scan")) || (args[i].equals("rt"))) {
             runMode = MODE_PROCESS;
         } else {
             System.out.println("Unknonwn mode " + args[i] + " - must be extract, align or analyse");
@@ -407,10 +410,13 @@ public class NanoOKOptions implements Serializable {
                 System.out.println("Error: You must specify a reference");
                 System.exit(1);
             }
+
             if (!referenceFile.endsWith(".fa") && !referenceFile.endsWith(".fasta")) {
                 System.out.println("Error: reference must specify a .fa or .fasta file");
                 System.exit(1);
             }
+            
+            checkParser();
         }
         
         if (runMode == MODE_PROCESS) {
@@ -451,7 +457,7 @@ public class NanoOKOptions implements Serializable {
                 
         initialiseBlastHandlers();
         
-        System.out.println("Number of cores: "+Runtime.getRuntime().availableProcessors());
+        //System.out.println("Number of cores: "+Runtime.getRuntime().availableProcessors());
         
         executor = new ThreadPoolExecutor(numThreads, numThreads, 10, TimeUnit.SECONDS, new LinkedBlockingQueue<Runnable>());
     }    
@@ -832,6 +838,14 @@ public class NanoOKOptions implements Serializable {
     public boolean isProcessingFailReads() {
         return processFailReads;
     }
+
+    /**
+     * Check if processing "skip" reads.
+     * @return true to process
+     */
+    public boolean isProcessingSkipReads() {
+        return processSkipReads;
+    }
     
     public boolean isProcessingComplementReads() {
         return processComplementReads;
@@ -974,6 +988,12 @@ public class NanoOKOptions implements Serializable {
             case "graphmap":
                 parser = new GraphMapParser(this, references);
                 break;
+            case "minimap2":
+                parser = new Minimap2Parser(this, references);
+                break;
+            case "ngmlr":
+                parser = new NgmlrParser(this, references);
+                break;
             default:
                 System.out.println("Aligner unknown!");
                 System.out.println("");
@@ -984,10 +1004,15 @@ public class NanoOKOptions implements Serializable {
         if (alignerParams != "") {
             parser.setAlignmentParams(alignerParams);
         }
-        
+                
         return parser;
     }    
     
+    public void checkParser() {
+        AlignmentFileParser parser = getParser();
+        parser.checkForIndex(getReferenceFile().substring(0, getReferenceFile().lastIndexOf('.')));
+    }
+    
     public boolean doKmerCounting() {
         return doKmerCounting;
     }
@@ -1198,9 +1223,6 @@ public class NanoOKOptions implements Serializable {
         if (this.isExtractingReads()) {
             checkAndMakeDirectory(this.getReadDir());
             
-            if (this.isBlastingRead()) {
-                checkAndMakeDirectory(this.getReadDir() + "_chunks");
-            }
             //if (this.isNewStyleDir()) {
             //    for (int i=READTYPE_PASS; i<=READTYPE_FAIL; i++) {
             //        String pf = NanoOKOptions.getPassFailFromInt(i);
@@ -1217,6 +1239,10 @@ public class NanoOKOptions implements Serializable {
             //    }
             //}                
         }
+
+        if (this.isBlastingRead()) {
+            checkAndMakeDirectory(this.getReadDir() + "_chunks");
+        }
         
         if (this.isAligningRead()) {
             checkAndMakeDirectory(this.getAlignerDir());
